#Import all Necessary Packages
import time
import motoron

#Initialise the I2C-connected Motoron HAT and provide it with a Variable.
#When using Stacked HATS you will need to create two variables (to represent both HATS) and
#provide the specific I2C Address for Both which you will write in the brackets
mc = motoron.MotoronI2C()

# Reset the controller to its default settings, then disable CRC (Cyclic Redundancy Check).  The bytes for
# each of these commands is shown here in case you want to implement them on
# your own without using the library.
mc.reinitialize()  # Bytes: 0x96 0x74
mc.disable_crc()  
mc.clear_reset_flag()

# Configure Motor 2 in regards to acceleration/deceleration with commands below
#The First value in the bracket Identifies Motor 2 as the target. The second
#Number in the bracket is the speed value. This is a value from 0 - 800, -->
# 0 is stopped, 800 is maxed acceleration)
mc.set_max_acceleration(2, 200)
mc.set_max_deceleration(2, 300)

#Below are two methods to either provide a timeout to the motors or prevent timeout altogether. Motors will stop once this timeout is reached if
#no constant input is received. Good to turn on when experimenting with code to prevent Runaway Motors. Default value is 1 second
#mc.disable_command_timeout()
mc.set_command_timeout_milliseconds(5000)
                
#Then we will turn Motor 2 On at speed of 800. Speed value can be from -800 to 800.
#MC.set_Speed(MOTOR 1 or 2, + and - Decide direction, Number decides the Speed)
#Below will rotate Motor 2 At maximum speed Clockwise (when looking from above with the motor standing upright)
mc.set_speed(2, 800)

#This will create a 4-second break until the next command. Note that the above command continues to have effect
#as the motor will continue to spin at top speed and the Timeout Command set above is 5 seconds.                
time.sleep(4)

#Below will Rotate Motor 2 At Half Speed Clockwise               
mc.set_speed(2, 400)

#This will create a 4-second break until the next command. Note that the above command continues to have the same effect.
time.sleep(4)

#Below will Rotate Motor 2 At Quarter Speed Anti-Clockwise                 
mc.set_speed(2, -200)

#This will create a 4-second break until the next command. Note that the above command continues to have the same effect.
time.sleep(4)

#By setting the speed value of 0 to the DC Motor results in braking (like engine braking). This will NOT de-energise the motor.
#Thus, with the below active, the DC motor would resist free spinning
mc.set_speed(2, 0)

#This will create a 4-second break until the next command. Note that the above command continues to have the same effect.
time.sleep(4)

#Below will de- energise the DC Motor allowing it to freely spin.                 
mc.coast_now()
